@@ -41,6 +41,8 @@ for the built (or installed) programs to be tested.
 
 # TODO: Some kind of direct test of the host selection algorithm.
 
+# TODO: Test host files containing \r.
+
 # TODO: Optionally run all discc tests under Valgrind, ElectricFence
 # or something similar.
 
@@ -290,7 +292,7 @@ class VersionOption_Case(SimpleDistCC_Case):
             out, err = self.runcmd("%s --version" % prog)
             assert out[-1] == '\n'
             out = out[:-1]
-            line1,trash = string.split(out, '\n')
+            line1,trash = string.split(out, '\n', 1)
             self.assert_re_match(r'^%s [\w.-]+ [.\w-]+ \(protocol.*\) \(default port 3632\)$'
                                  % prog, line1)
 
@@ -417,6 +419,8 @@ class ScanArgs_Case(SimpleDistCC_Case):
 
                  ("gcc -xassembler-with-cpp foo.c", "local"),
                  ("gcc -x assembler-with-cpp foo.c", "local"),
+
+                 ("gcc -specs=foo.specs foo.c", "local"),
                  ]
         for tup in cases:
             apply(self.checkScanArgs, tup)
@@ -981,7 +985,7 @@ class MissingCompiler_Case(CompileHello_Case):
         
 
 
-class RemoteAssemble_Case(CompileHello_Case):
+class RemoteAssemble_Case(WithDaemon_Case):
     """Test remote assembly of a .s file."""
 
     # We have a rather tricky method for testing assembly code when we
@@ -989,8 +993,6 @@ class RemoteAssemble_Case(CompileHello_Case):
     # everywhere, though perhaps not.
     asm_source = """
         .file	"foo.c"
-	.version	"01.01"
-gcc2_compiled.:
 .globl msg
 .section	.rodata
 .LC0:
@@ -1001,48 +1003,21 @@ gcc2_compiled.:
 	.size	 msg,4
 msg:
 	.long .LC0
-	.ident	"GCC: (GNU) 2.95.4 20011002 (Debian prerelease)"
 """
 
-    def source(self):
-            return """
-#include <stdio.h>
-
-extern const char *msg;
-
-int main(void) {
-    puts(msg);
-    return 0;
-}
-"""
     asm_filename = 'test2.s'
 
     def setup(self):
-        CompileHello_Case.setup(self)
+        WithDaemon_Case.setup(self)
         open(self.asm_filename, 'wt').write(self.asm_source)
-        
-        # TODO: Delete temp files
 
     def compile(self):
         # Need to build both the C file and the assembly file
         self.runcmd("distcc " + _gcc + " -o test2.o -c test2.s")
-        self.runcmd("distcc " + _gcc + " -o testtmp.o -c testtmp.c")
-        self.runcmd(self.linkCmd())
-
-    def asmCmd(self):
-        return "distcc " + _gcc + " -o test2.o -c %s" % (self.asm_filename)
-
-    def linkCmd(self):
-        return "distcc " + _gcc + " -o testtmp testtmp.o test2.o"
-
-    def runtest(self):
-        if sys.platform == 'linux2':
-            CompileHello_Case.runtest (self)
-        else:
-            raise comfychair.NotRunError ('Linux x86 only')
 
 
-class PreprocessAsm_Case(RemoteAssemble_Case):
+
+class PreprocessAsm_Case(WithDaemon_Case):
     """Run preprocessor locally on assembly, then compile locally."""
     asm_source = """
 #define MSG "hello world"
@@ -1058,19 +1033,19 @@ gcc2_compiled.:
 msg:
 	.long .LC0
 """
-    asm_filename = 'test2.S'
+
+    def setup(self):
+        WithDaemon_Case.setup(self)
+        open('test2.S', 'wt').write(self.asm_source)
     
     def compile(self):
         if sys.platform == 'linux2':
-            self.runcmd("distcc " + _gcc + " -o test2.o -c test2.S")
-            self.runcmd("distcc " + _gcc + " -o testtmp.o -c testtmp.c")
-            self.runcmd("distcc " + _gcc + " -o testtmp testtmp.o test2.o")
+            self.runcmd("distcc -o test2.o -c test2.S")
 
     def runtest(self):
-        if sys.platform == 'linux2':
-            RemoteAssemble_Case.runtest (self)
-        else:
-            raise comfychair.NotRunError ('Linux x86 only')
+        self.compile()
+
+
 
 
 class ModeBits_Case(CompileHello_Case):
